[Libreoffice-commits] core.git: compilerplugins/clang include/vcl vcl/inc vcl/qt5 vcl/quartz vcl/source vcl/unx vcl/win

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Tue Aug 21 22:25:27 UTC 2018


 compilerplugins/clang/mergeclasses.results     |    1 
 compilerplugins/clang/unusedmethods.results    |    2 -
 include/vcl/outdev.hxx                         |    2 -
 vcl/inc/PhysicalFontCollection.hxx             |    4 +--
 vcl/inc/PhysicalFontFace.hxx                   |    6 ++--
 vcl/inc/PhysicalFontFamily.hxx                 |    2 -
 vcl/inc/fontinstance.hxx                       |    8 +++---
 vcl/inc/fontselect.hxx                         |   10 +++----
 vcl/inc/impfontcache.hxx                       |   10 +++----
 vcl/inc/impfontmetricdata.hxx                  |    4 +--
 vcl/inc/outdev.h                               |    4 +--
 vcl/inc/qt5/Qt5Font.hxx                        |    4 +--
 vcl/inc/qt5/Qt5FontFace.hxx                    |    4 +--
 vcl/inc/quartz/salgdi.h                        |    6 ++--
 vcl/inc/salgdi.hxx                             |    2 -
 vcl/inc/unx/fontmanager.hxx                    |    4 +--
 vcl/inc/unx/freetype_glyphcache.hxx            |    6 ++--
 vcl/inc/unx/salgdi.h                           |    2 -
 vcl/inc/win/salgdi.h                           |    8 +++---
 vcl/inc/win/winlayout.hxx                      |    4 +--
 vcl/qt5/Qt5Font.cxx                            |    2 -
 vcl/qt5/Qt5FontFace.cxx                        |    2 -
 vcl/quartz/ctfonts.cxx                         |    4 +--
 vcl/quartz/salgdi.cxx                          |    6 ++--
 vcl/source/font/PhysicalFontCollection.cxx     |    8 +++---
 vcl/source/font/PhysicalFontFace.cxx           |    4 +--
 vcl/source/font/PhysicalFontFamily.cxx         |    2 -
 vcl/source/font/fontcache.cxx                  |   14 +++++-----
 vcl/source/font/fontinstance.cxx               |    4 +--
 vcl/source/font/fontmetric.cxx                 |    2 -
 vcl/source/font/fontselect.cxx                 |   14 +++++-----
 vcl/source/gdi/CommonSalLayout.cxx             |    2 -
 vcl/source/gdi/pdfwriter_impl.hxx              |    2 -
 vcl/source/outdev/font.cxx                     |    2 -
 vcl/source/outdev/text.cxx                     |    2 -
 vcl/unx/generic/fontmanager/fontconfig.cxx     |    2 -
 vcl/unx/generic/fontmanager/fontsubst.cxx      |   26 ++++++++++----------
 vcl/unx/generic/gdi/cairotextrender.cxx        |    2 -
 vcl/unx/generic/glyphs/freetype_glyphcache.cxx |    4 +--
 vcl/unx/generic/glyphs/glyphcache.cxx          |   14 +++++-----
 vcl/unx/generic/print/genpspgraphics.cxx       |    2 -
 vcl/win/gdi/salfont.cxx                        |   32 ++++++++++++-------------
 vcl/win/gdi/winlayout.cxx                      |    4 +--
 43 files changed, 124 insertions(+), 125 deletions(-)

New commits:
commit cbce9044b075f22a936c8a15bacf3cb57130c984
Author:     Caolán McNamara <caolanm at redhat.com>
AuthorDate: Tue Aug 21 09:39:50 2018 +0100
Commit:     Caolán McNamara <caolanm at redhat.com>
CommitDate: Wed Aug 22 00:25:03 2018 +0200

    rename FontSelectPatternAttributes to FontSelectPattern
    
    Change-Id: I2c018e2e61707c0d89178b0cb38a0918906e23cb
    Reviewed-on: https://gerrit.libreoffice.org/59390
    Tested-by: Jenkins
    Reviewed-by: Caolán McNamara <caolanm at redhat.com>
    Tested-by: Caolán McNamara <caolanm at redhat.com>

diff --git a/compilerplugins/clang/mergeclasses.results b/compilerplugins/clang/mergeclasses.results
index 454c327d650a..e805ec5f0923 100644
--- a/compilerplugins/clang/mergeclasses.results
+++ b/compilerplugins/clang/mergeclasses.results
@@ -36,7 +36,6 @@ merge FailTest with testMathMalformedXml
 merge FillTypeLB with SvxFillTypeBox
 merge FmGridListener with FmXGridPeer::GridListenerDelegator
 merge FmXDisposeListener with DisposeListenerGridBridge
-merge FontSelectPatternAttributes with FontSelectPattern
 merge GLWindow with GLX11Window
 merge GroupTable with PPTWriterBase
 merge HostDetailsContainer with DavDetailsContainer
diff --git a/compilerplugins/clang/unusedmethods.results b/compilerplugins/clang/unusedmethods.results
index 020cf3c92d0f..e58c8e01474d 100644
--- a/compilerplugins/clang/unusedmethods.results
+++ b/compilerplugins/clang/unusedmethods.results
@@ -1167,7 +1167,7 @@ vcl/inc/fontinstance.hxx:63
 vcl/inc/fontinstance.hxx:80
     void LogicalFontInstance::ReleaseHbFont()
 vcl/inc/fontselect.hxx:48
-    _Bool FontSelectPatternAttributes::operator!=(const class FontSelectPatternAttributes &) const
+    _Bool FontSelectPattern::operator!=(const class FontSelectPattern &) const
 vcl/inc/headless/svpgdi.hxx:230
     void SvpSalGraphics::drawBitmap(const struct SalTwoRect &,struct BitmapBuffer *,enum _cairo_operator)
 vcl/inc/impgraph.hxx:57
diff --git a/include/vcl/outdev.hxx b/include/vcl/outdev.hxx
index 7f5d55d15641..54c22e6cc7fd 100644
--- a/include/vcl/outdev.hxx
+++ b/include/vcl/outdev.hxx
@@ -87,7 +87,7 @@ class VirtualDevice;
 struct SalTwoRect;
 class VirtualDevice;
 class Printer;
-class FontSelectPatternAttributes;
+class FontSelectPattern;
 class VCLXGraphics;
 class OutDevStateStack;
 struct BitmapSystemData;
diff --git a/vcl/inc/PhysicalFontCollection.hxx b/vcl/inc/PhysicalFontCollection.hxx
index 43423b72a37a..9fc08ff4a40b 100644
--- a/vcl/inc/PhysicalFontCollection.hxx
+++ b/vcl/inc/PhysicalFontCollection.hxx
@@ -49,13 +49,13 @@ public:
     // find the device font family
     PhysicalFontFamily*     FindFontFamily( const OUString& rFontName ) const;
     PhysicalFontFamily*     FindOrCreateFontFamily( const OUString &rFamilyName );
-    PhysicalFontFamily*     FindFontFamily( FontSelectPatternAttributes& ) const;
+    PhysicalFontFamily*     FindFontFamily( FontSelectPattern& ) const;
     PhysicalFontFamily*     FindFontFamilyByTokenNames(const OUString& rTokenStr) const;
     PhysicalFontFamily*     FindFontFamilyByAttributes(ImplFontAttrs nSearchType, FontWeight, FontWidth,
                                              FontItalic, const OUString& rSearchFamily) const;
 
     // suggest fonts for glyph fallback
-    PhysicalFontFamily*     GetGlyphFallbackFont( FontSelectPatternAttributes&,
+    PhysicalFontFamily*     GetGlyphFallbackFont( FontSelectPattern&,
                                                   LogicalFontInstance* pLogicalFont,
                                                   OUString& rMissingCodes, int nFallbackLevel ) const;
 
diff --git a/vcl/inc/PhysicalFontFace.hxx b/vcl/inc/PhysicalFontFace.hxx
index 9947ac759cf2..c350a6c81649 100644
--- a/vcl/inc/PhysicalFontFace.hxx
+++ b/vcl/inc/PhysicalFontFace.hxx
@@ -28,7 +28,7 @@
 
 class LogicalFontInstance;
 struct FontMatchStatus;
-class FontSelectPatternAttributes;
+class FontSelectPattern;
 class PhysicalFontFamily;
 
 struct FontMatchStatus
@@ -54,13 +54,13 @@ public:
 class VCL_PLUGIN_PUBLIC PhysicalFontFace : public FontAttributes, public salhelper::SimpleReferenceObject
 {
 public:
-    virtual rtl::Reference<LogicalFontInstance> CreateFontInstance(const FontSelectPatternAttributes&) const;
+    virtual rtl::Reference<LogicalFontInstance> CreateFontInstance(const FontSelectPattern&) const;
 
     int                     GetHeight() const           { return mnHeight; }
     int                     GetWidth() const            { return mnWidth; }
     virtual sal_IntPtr      GetFontId() const = 0;
 
-    bool                    IsBetterMatch( const FontSelectPatternAttributes&, FontMatchStatus& ) const;
+    bool                    IsBetterMatch( const FontSelectPattern&, FontMatchStatus& ) const;
     sal_Int32               CompareWithSize( const PhysicalFontFace& ) const;
     sal_Int32               CompareIgnoreSize( const PhysicalFontFace& ) const;
 
diff --git a/vcl/inc/PhysicalFontFamily.hxx b/vcl/inc/PhysicalFontFamily.hxx
index 8944c0d410ff..990256590c88 100644
--- a/vcl/inc/PhysicalFontFamily.hxx
+++ b/vcl/inc/PhysicalFontFamily.hxx
@@ -69,7 +69,7 @@ public:
 
     void                AddFontFace( PhysicalFontFace* );
 
-    PhysicalFontFace*   FindBestFontFace( const FontSelectPatternAttributes& rFSD ) const;
+    PhysicalFontFace*   FindBestFontFace( const FontSelectPattern& rFSD ) const;
 
     void                UpdateDevFontList( ImplDeviceFontList& ) const;
     void                UpdateCloneFontList(PhysicalFontCollection&) const;
diff --git a/vcl/inc/fontinstance.hxx b/vcl/inc/fontinstance.hxx
index e5b42e831ea6..597c747553ac 100644
--- a/vcl/inc/fontinstance.hxx
+++ b/vcl/inc/fontinstance.hxx
@@ -39,7 +39,7 @@ class PhysicalFontFace;
 class VCL_PLUGIN_PUBLIC LogicalFontInstance : public salhelper::SimpleReferenceObject
 {
     // just declaring the factory function doesn't work AKA
-    // friend LogicalFontInstance* PhysicalFontFace::CreateFontInstance(const FontSelectPatternAttributes&) const;
+    // friend LogicalFontInstance* PhysicalFontFace::CreateFontInstance(const FontSelectPattern&) const;
     friend class PhysicalFontFace;
     friend class ImplFontCache;
 
@@ -62,7 +62,7 @@ public: // TODO: make data members private
     void SetAverageWidthFactor(double nFactor) { m_nAveWidthFactor = nFactor; }
     void SetNonAntialiased(bool bNonAntialiased);
     double GetAverageWidthFactor() const { return m_nAveWidthFactor; }
-    const FontSelectPatternAttributes& GetFontSelectPattern() const { return m_aFontSelData; }
+    const FontSelectPattern& GetFontSelectPattern() const { return m_aFontSelData; }
 
     const PhysicalFontFace* GetFontFace() const { return m_pFontFace.get(); }
     const ImplFontCache* GetFontCache() const { return mpFontCache; }
@@ -73,7 +73,7 @@ public: // TODO: make data members private
     static inline void DecodeOpenTypeTag(const uint32_t nTableTag, char* pTagName);
 
 protected:
-    explicit LogicalFontInstance(const PhysicalFontFace&, const FontSelectPatternAttributes&);
+    explicit LogicalFontInstance(const PhysicalFontFace&, const FontSelectPattern&);
 
     // Takes ownership of pHbFace.
     hb_font_t* InitHbFont(hb_face_t* pHbFace) const;
@@ -87,7 +87,7 @@ private:
     typedef ::std::unordered_map< ::std::pair<sal_UCS4,FontWeight>, OUString > UnicodeFallbackList;
     std::unique_ptr<UnicodeFallbackList> mpUnicodeFallbackList;
     ImplFontCache * mpFontCache;
-    const FontSelectPatternAttributes m_aFontSelData;
+    const FontSelectPattern m_aFontSelData;
     hb_font_t* m_pHbFont;
     double m_nAveWidthFactor;
     rtl::Reference<PhysicalFontFace> m_pFontFace;
diff --git a/vcl/inc/fontselect.hxx b/vcl/inc/fontselect.hxx
index 0350412366fe..220bb32d9861 100644
--- a/vcl/inc/fontselect.hxx
+++ b/vcl/inc/fontselect.hxx
@@ -33,19 +33,19 @@ class LogicalFontInstance;
 class PhysicalFontFace;
 class Size;
 
-class FontSelectPatternAttributes : public FontAttributes
+class FontSelectPattern : public FontAttributes
 {
 public:
-                    FontSelectPatternAttributes( const vcl::Font&, const OUString& rSearchName,
+                    FontSelectPattern( const vcl::Font&, const OUString& rSearchName,
                                                  const Size&, float fExactHeight );
 #ifdef _WIN32
-                    FontSelectPatternAttributes( const PhysicalFontFace&, const Size&,
+                    FontSelectPattern( const PhysicalFontFace&, const Size&,
                                                  float fExactHeight, int nOrientation, bool bVertical );
 #endif
 
     size_t          hashCode() const;
-    bool operator==(const FontSelectPatternAttributes& rOther) const;
-    bool operator!=(const FontSelectPatternAttributes& rOther) const
+    bool operator==(const FontSelectPattern& rOther) const;
+    bool operator!=(const FontSelectPattern& rOther) const
     {
         return !(*this == rOther);
     }
diff --git a/vcl/inc/impfontcache.hxx b/vcl/inc/impfontcache.hxx
index e8b7b191137b..10a38540e67b 100644
--- a/vcl/inc/impfontcache.hxx
+++ b/vcl/inc/impfontcache.hxx
@@ -37,12 +37,12 @@ private:
     LogicalFontInstance* mpLastHitCacheEntry; ///< keeps the last hit cache entry
 
     // cache of recently used font instances
-    struct IFSD_Equal { bool operator()( const FontSelectPatternAttributes&, const FontSelectPatternAttributes& ) const; };
-    struct IFSD_Hash { size_t operator()( const FontSelectPatternAttributes& ) const; };
-    typedef std::unordered_map<FontSelectPatternAttributes, rtl::Reference<LogicalFontInstance>, IFSD_Hash, IFSD_Equal> FontInstanceList;
+    struct IFSD_Equal { bool operator()( const FontSelectPattern&, const FontSelectPattern& ) const; };
+    struct IFSD_Hash { size_t operator()( const FontSelectPattern& ) const; };
+    typedef std::unordered_map<FontSelectPattern, rtl::Reference<LogicalFontInstance>, IFSD_Hash, IFSD_Equal> FontInstanceList;
     FontInstanceList    maFontInstanceList;
 
-    rtl::Reference<LogicalFontInstance> GetFontInstance(PhysicalFontCollection const*, FontSelectPatternAttributes&);
+    rtl::Reference<LogicalFontInstance> GetFontInstance(PhysicalFontCollection const*, FontSelectPattern&);
 
 public:
                         ImplFontCache();
@@ -50,7 +50,7 @@ public:
 
     rtl::Reference<LogicalFontInstance> GetFontInstance( PhysicalFontCollection const *,
                              const vcl::Font&, const Size& rPixelSize, float fExactHeight);
-    rtl::Reference<LogicalFontInstance> GetGlyphFallbackFont( PhysicalFontCollection const *, FontSelectPatternAttributes&,
+    rtl::Reference<LogicalFontInstance> GetGlyphFallbackFont( PhysicalFontCollection const *, FontSelectPattern&,
                             LogicalFontInstance* pLogicalFont,
                             int nFallbackLevel, OUString& rMissingCodes );
 
diff --git a/vcl/inc/impfontmetricdata.hxx b/vcl/inc/impfontmetricdata.hxx
index f11b763be126..28e0ab3798a2 100644
--- a/vcl/inc/impfontmetricdata.hxx
+++ b/vcl/inc/impfontmetricdata.hxx
@@ -31,12 +31,12 @@ class ImplFontMetricData;
 typedef tools::SvRef<ImplFontMetricData> ImplFontMetricDataRef;
 
 class OutputDevice;
-class FontSelectPatternAttributes;
+class FontSelectPattern;
 
 class VCL_DLLPUBLIC ImplFontMetricData : public FontAttributes, public SvRefBase
 {
 public:
-    explicit        ImplFontMetricData( const FontSelectPatternAttributes& );
+    explicit        ImplFontMetricData( const FontSelectPattern& );
 
     // font instance attributes from the font request
     long            GetWidth() const                                                { return mnWidth; }
diff --git a/vcl/inc/outdev.h b/vcl/inc/outdev.h
index 5ac5cc0df0b4..f0ea310b1788 100644
--- a/vcl/inc/outdev.h
+++ b/vcl/inc/outdev.h
@@ -110,7 +110,7 @@ class ImplPreMatchFontSubstitution
 :   public ImplFontSubstitution
 {
 public:
-    virtual bool FindFontSubstitute(FontSelectPatternAttributes&)  const = 0;
+    virtual bool FindFontSubstitute(FontSelectPattern&)  const = 0;
 };
 
 // ImplGlyphFallbackFontSubstitution
@@ -119,7 +119,7 @@ class ImplGlyphFallbackFontSubstitution
 :   public ImplFontSubstitution
 {
 public:
-    virtual bool FindFontSubstitute(FontSelectPatternAttributes&, LogicalFontInstance* pLogicalFont, OUString& rMissingCodes) const = 0;
+    virtual bool FindFontSubstitute(FontSelectPattern&, LogicalFontInstance* pLogicalFont, OUString& rMissingCodes) const = 0;
 };
 
 namespace vcl { struct ControlLayoutData; }
diff --git a/vcl/inc/qt5/Qt5Font.hxx b/vcl/inc/qt5/Qt5Font.hxx
index ca975502c920..034cda35c2d4 100644
--- a/vcl/inc/qt5/Qt5Font.hxx
+++ b/vcl/inc/qt5/Qt5Font.hxx
@@ -28,11 +28,11 @@
 class Qt5Font final : public QFont, public LogicalFontInstance
 {
     friend rtl::Reference<LogicalFontInstance>
-    Qt5FontFace::CreateFontInstance(const FontSelectPatternAttributes&) const;
+    Qt5FontFace::CreateFontInstance(const FontSelectPattern&) const;
 
     virtual hb_font_t* ImplInitHbFont() override;
 
-    explicit Qt5Font(const PhysicalFontFace&, const FontSelectPatternAttributes&);
+    explicit Qt5Font(const PhysicalFontFace&, const FontSelectPattern&);
 
 public:
     virtual ~Qt5Font() override;
diff --git a/vcl/inc/qt5/Qt5FontFace.hxx b/vcl/inc/qt5/Qt5FontFace.hxx
index 3fd6c1599b56..c653b4be6f6e 100644
--- a/vcl/inc/qt5/Qt5FontFace.hxx
+++ b/vcl/inc/qt5/Qt5FontFace.hxx
@@ -28,7 +28,7 @@
 #include <QtCore/QString>
 
 class FontAttributes;
-class FontSelectPatternAttributes;
+class FontSelectPattern;
 class QFont;
 
 class Qt5FontFace : public PhysicalFontFace
@@ -48,7 +48,7 @@ public:
     bool HasChar(sal_uInt32 cChar) const;
 
     rtl::Reference<LogicalFontInstance>
-    CreateFontInstance(const FontSelectPatternAttributes& rFSD) const override;
+    CreateFontInstance(const FontSelectPattern& rFSD) const override;
 
 protected:
     Qt5FontFace(const Qt5FontFace&);
diff --git a/vcl/inc/quartz/salgdi.h b/vcl/inc/quartz/salgdi.h
index 87b3a028ab37..31a8353a17ed 100644
--- a/vcl/inc/quartz/salgdi.h
+++ b/vcl/inc/quartz/salgdi.h
@@ -68,7 +68,7 @@ public:
     bool                            GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const;
     bool                            HasChar( sal_uInt32 cChar ) const;
 
-    rtl::Reference<LogicalFontInstance> CreateFontInstance(const FontSelectPatternAttributes&) const override;
+    rtl::Reference<LogicalFontInstance> CreateFontInstance(const FontSelectPattern&) const override;
 
 private:
     const sal_IntPtr                mnFontId;
@@ -79,7 +79,7 @@ private:
 
 class CoreTextStyle : public LogicalFontInstance
 {
-    friend rtl::Reference<LogicalFontInstance> CoreTextFontFace::CreateFontInstance(const FontSelectPatternAttributes&) const;
+    friend rtl::Reference<LogicalFontInstance> CoreTextFontFace::CreateFontInstance(const FontSelectPattern&) const;
 
 public:
     ~CoreTextStyle() override;
@@ -96,7 +96,7 @@ public:
     float               mfFontRotation;
 
 private:
-    explicit CoreTextStyle(const PhysicalFontFace&, const FontSelectPatternAttributes&);
+    explicit CoreTextStyle(const PhysicalFontFace&, const FontSelectPattern&);
 
     virtual hb_font_t* ImplInitHbFont() override;
 
diff --git a/vcl/inc/salgdi.hxx b/vcl/inc/salgdi.hxx
index f6c3aa2d3870..8744c8f77573 100644
--- a/vcl/inc/salgdi.hxx
+++ b/vcl/inc/salgdi.hxx
@@ -34,7 +34,7 @@
 
 class PhysicalFontCollection;
 class SalBitmap;
-class FontSelectPatternAttributes;
+class FontSelectPattern;
 class FontAttributes;
 class PhysicalFontFace;
 class SalLayout;
diff --git a/vcl/inc/unx/fontmanager.hxx b/vcl/inc/unx/fontmanager.hxx
index bd05ec1b4ce9..e19b5f3fc9ae 100644
--- a/vcl/inc/unx/fontmanager.hxx
+++ b/vcl/inc/unx/fontmanager.hxx
@@ -44,7 +44,7 @@
 
 class FontSubsetInfo;
 class FontConfigFontOptions;
-class FontSelectPatternAttributes;
+class FontSelectPattern;
 class GenericUnixSalData;
 
 namespace psp {
@@ -310,7 +310,7 @@ public:
     void matchFont( FastPrintFontInfo& rInfo, const css::lang::Locale& rLocale );
     static FontConfigFontOptions* getFontOptions( const FastPrintFontInfo&, int nSize);
 
-    void Substitute(FontSelectPatternAttributes &rPattern, OUString& rMissingCodes);
+    void Substitute(FontSelectPattern &rPattern, OUString& rMissingCodes);
 
 };
 
diff --git a/vcl/inc/unx/freetype_glyphcache.hxx b/vcl/inc/unx/freetype_glyphcache.hxx
index 2f09f3069465..b1db824ccdd3 100644
--- a/vcl/inc/unx/freetype_glyphcache.hxx
+++ b/vcl/inc/unx/freetype_glyphcache.hxx
@@ -114,21 +114,21 @@ private:
 public:
                             FreetypeFontFace( FreetypeFontInfo*, const FontAttributes& );
 
-    virtual rtl::Reference<LogicalFontInstance> CreateFontInstance( const FontSelectPatternAttributes& ) const override;
+    virtual rtl::Reference<LogicalFontInstance> CreateFontInstance( const FontSelectPattern& ) const override;
     virtual sal_IntPtr      GetFontId() const override { return mpFreetypeFontInfo->GetFontId(); }
 };
 
 // a class for cache entries for physical font instances that are based on serverfonts
 class VCL_DLLPUBLIC FreetypeFontInstance : public LogicalFontInstance
 {
-    friend rtl::Reference<LogicalFontInstance> FreetypeFontFace::CreateFontInstance(const FontSelectPatternAttributes&) const;
+    friend rtl::Reference<LogicalFontInstance> FreetypeFontFace::CreateFontInstance(const FontSelectPattern&) const;
 
     FreetypeFont* mpFreetypeFont;
 
     virtual hb_font_t* ImplInitHbFont() override;
 
 protected:
-    explicit FreetypeFontInstance(const PhysicalFontFace& rPFF, const FontSelectPatternAttributes& rFSP);
+    explicit FreetypeFontInstance(const PhysicalFontFace& rPFF, const FontSelectPattern& rFSP);
 
 public:
     virtual ~FreetypeFontInstance() override;
diff --git a/vcl/inc/unx/salgdi.h b/vcl/inc/unx/salgdi.h
index 057d1953caab..408434f9062e 100644
--- a/vcl/inc/unx/salgdi.h
+++ b/vcl/inc/unx/salgdi.h
@@ -43,7 +43,7 @@
 typedef unsigned long Pixel;
 
 class FontAttributes;
-class FontSelectPatternAttributes;
+class FontSelectPattern;
 class SalBitmap;
 class SalColormap;
 class SalDisplay;
diff --git a/vcl/inc/win/salgdi.h b/vcl/inc/win/salgdi.h
index 27a5e8b46ebe..c55193e255e9 100644
--- a/vcl/inc/win/salgdi.h
+++ b/vcl/inc/win/salgdi.h
@@ -42,7 +42,7 @@
 #include <hb-ot.h>
 #include <dwrite.h>
 
-class FontSelectPatternAttributes;
+class FontSelectPattern;
 class WinFontInstance;
 class ImplFontAttrCache;
 class OpenGLTexture;
@@ -63,7 +63,7 @@ public:
                                 BYTE nPitchAndFamily  );
     virtual                 ~WinFontFace() override;
 
-    virtual rtl::Reference<LogicalFontInstance> CreateFontInstance( const FontSelectPatternAttributes& ) const override;
+    virtual rtl::Reference<LogicalFontInstance> CreateFontInstance( const FontSelectPattern& ) const override;
     virtual sal_IntPtr      GetFontId() const override;
     void                    SetFontId( sal_IntPtr nId ) { mnId = nId; }
     void                    UpdateFromHDC( HDC ) const;
@@ -185,7 +185,7 @@ private:
 
     bool CacheGlyphs(const GenericSalLayout& rLayout);
     bool DrawCachedGlyphs(const GenericSalLayout& rLayout);
-    HFONT ImplDoSetFont(FontSelectPatternAttributes const & i_rFont, const PhysicalFontFace * i_pFontFace, float& o_rFontScale, HFONT& o_rOldFont);
+    HFONT ImplDoSetFont(FontSelectPattern const & i_rFont, const PhysicalFontFace * i_pFontFace, float& o_rFontScale, HFONT& o_rOldFont);
 
 public:
     HDC getHDC() const { return mhLocalDC; }
@@ -402,7 +402,7 @@ public:
 // Init/Deinit Graphics
 void    ImplUpdateSysColorEntries();
 int     ImplIsSysColorEntry( Color nColor );
-void    ImplGetLogFontFromFontSelect( HDC, const FontSelectPatternAttributes*,
+void    ImplGetLogFontFromFontSelect( HDC, const FontSelectPattern*,
             const PhysicalFontFace*, LOGFONTW& );
 
 #define MAX_64KSALPOINTS    ((((sal_uInt16)0xFFFF)-8)/sizeof(POINTS))
diff --git a/vcl/inc/win/winlayout.hxx b/vcl/inc/win/winlayout.hxx
index 4c4b7feab468..598d90c60588 100644
--- a/vcl/inc/win/winlayout.hxx
+++ b/vcl/inc/win/winlayout.hxx
@@ -145,7 +145,7 @@ public:
 // win32 specific physical font instance
 class WinFontInstance : public LogicalFontInstance
 {
-    friend rtl::Reference<LogicalFontInstance> WinFontFace::CreateFontInstance(const FontSelectPatternAttributes&) const;
+    friend rtl::Reference<LogicalFontInstance> WinFontFace::CreateFontInstance(const FontSelectPattern&) const;
 
 public:
     virtual ~WinFontInstance() override;
@@ -162,7 +162,7 @@ public:
     void UnsetHFONT() { m_hFont = nullptr; }
 
 private:
-    explicit WinFontInstance(const PhysicalFontFace&, const FontSelectPatternAttributes&);
+    explicit WinFontInstance(const PhysicalFontFace&, const FontSelectPattern&);
 
     virtual hb_font_t* ImplInitHbFont() override;
 
diff --git a/vcl/qt5/Qt5Font.cxx b/vcl/qt5/Qt5Font.cxx
index a4d4d1d08a0b..dc393dd1cae8 100644
--- a/vcl/qt5/Qt5Font.cxx
+++ b/vcl/qt5/Qt5Font.cxx
@@ -55,7 +55,7 @@ static QFont::Weight GetQFontWeight(FontWeight eWeight)
     return QFont::Normal;
 }
 
-Qt5Font::Qt5Font(const PhysicalFontFace& rPFF, const FontSelectPatternAttributes& rFSP)
+Qt5Font::Qt5Font(const PhysicalFontFace& rPFF, const FontSelectPattern& rFSP)
     : LogicalFontInstance(rPFF, rFSP)
 {
     setFamily(toQString(rPFF.GetFamilyName()));
diff --git a/vcl/qt5/Qt5FontFace.cxx b/vcl/qt5/Qt5FontFace.cxx
index d122019307d2..10f79aa559bd 100644
--- a/vcl/qt5/Qt5FontFace.cxx
+++ b/vcl/qt5/Qt5FontFace.cxx
@@ -117,7 +117,7 @@ Qt5FontFace::~Qt5FontFace() {}
 sal_IntPtr Qt5FontFace::GetFontId() const { return reinterpret_cast<sal_IntPtr>(&m_aFontId); }
 
 rtl::Reference<LogicalFontInstance>
-Qt5FontFace::CreateFontInstance(const FontSelectPatternAttributes& rFSD) const
+Qt5FontFace::CreateFontInstance(const FontSelectPattern& rFSD) const
 {
     return new Qt5Font(*this, rFSD);
 }
diff --git a/vcl/quartz/ctfonts.cxx b/vcl/quartz/ctfonts.cxx
index a3836f66123c..7894cfef0c8f 100644
--- a/vcl/quartz/ctfonts.cxx
+++ b/vcl/quartz/ctfonts.cxx
@@ -45,7 +45,7 @@ inline double toRadian(int nDegree)
     return nDegree * (M_PI / 1800.0);
 }
 
-CoreTextStyle::CoreTextStyle(const PhysicalFontFace& rPFF, const FontSelectPatternAttributes& rFSP)
+CoreTextStyle::CoreTextStyle(const PhysicalFontFace& rPFF, const FontSelectPattern& rFSP)
     : LogicalFontInstance(rPFF, rFSP)
     , mfFontStretch( 1.0 )
     , mfFontRotation( 0.0 )
@@ -284,7 +284,7 @@ hb_font_t* CoreTextStyle::ImplInitHbFont()
     return InitHbFont(pHbFace);
 }
 
-rtl::Reference<LogicalFontInstance> CoreTextFontFace::CreateFontInstance(const FontSelectPatternAttributes& rFSD) const
+rtl::Reference<LogicalFontInstance> CoreTextFontFace::CreateFontInstance(const FontSelectPattern& rFSD) const
 {
     return new CoreTextStyle(*this, rFSD);
 }
diff --git a/vcl/quartz/salgdi.cxx b/vcl/quartz/salgdi.cxx
index 6b9350bb4427..db595a5aa37b 100644
--- a/vcl/quartz/salgdi.cxx
+++ b/vcl/quartz/salgdi.cxx
@@ -60,10 +60,10 @@ class CoreTextGlyphFallbackSubstititution
 :    public ImplGlyphFallbackFontSubstitution
 {
 public:
-    bool FindFontSubstitute(FontSelectPatternAttributes&, LogicalFontInstance* pLogicalFont, OUString&) const override;
+    bool FindFontSubstitute(FontSelectPattern&, LogicalFontInstance* pLogicalFont, OUString&) const override;
 };
 
-bool CoreTextGlyphFallbackSubstititution::FindFontSubstitute(FontSelectPatternAttributes& rPattern, LogicalFontInstance* pLogicalFont,
+bool CoreTextGlyphFallbackSubstititution::FindFontSubstitute(FontSelectPattern& rPattern, LogicalFontInstance* pLogicalFont,
     OUString& rMissingChars) const
 {
     bool bFound = false;
@@ -394,7 +394,7 @@ bool AquaSalGraphics::GetGlyphBoundRect(const GlyphItem& rGlyph, tools::Rectangl
 void AquaSalGraphics::DrawTextLayout(const GenericSalLayout& rLayout)
 {
     const CoreTextStyle& rStyle = *static_cast<const CoreTextStyle*>(&rLayout.GetFont());
-    const FontSelectPatternAttributes& rFontSelect = rStyle.GetFontSelectPattern();
+    const FontSelectPattern& rFontSelect = rStyle.GetFontSelectPattern();
     if (rFontSelect.mnHeight == 0)
         return;
 
diff --git a/vcl/source/font/PhysicalFontCollection.cxx b/vcl/source/font/PhysicalFontCollection.cxx
index 821da5cdf937..a495c9391f21 100644
--- a/vcl/source/font/PhysicalFontCollection.cxx
+++ b/vcl/source/font/PhysicalFontCollection.cxx
@@ -170,7 +170,7 @@ void PhysicalFontCollection::ImplInitGenericGlyphFallback() const
     mpFallbackList  = std::move(pFallbackList);
 }
 
-PhysicalFontFamily* PhysicalFontCollection::GetGlyphFallbackFont( FontSelectPatternAttributes& rFontSelData,
+PhysicalFontFamily* PhysicalFontCollection::GetGlyphFallbackFont( FontSelectPattern& rFontSelData,
                                                                   LogicalFontInstance* pFontInstance,
                                                                   OUString& rMissingCodes,
                                                                   int nFallbackLevel ) const
@@ -929,7 +929,7 @@ static const std::map<OUString, OUString> aMetricCompatibleMap =
     { "Calibri",         "Carlito" },
 };
 
-static bool FindMetricCompatibleFont(FontSelectPatternAttributes& rFontSelData)
+static bool FindMetricCompatibleFont(FontSelectPattern& rFontSelData)
 {
     for (const auto& aSub : aMetricCompatibleMap)
     {
@@ -943,7 +943,7 @@ static bool FindMetricCompatibleFont(FontSelectPatternAttributes& rFontSelData)
     return false;
 }
 
-PhysicalFontFamily* PhysicalFontCollection::FindFontFamily( FontSelectPatternAttributes& rFSD ) const
+PhysicalFontFamily* PhysicalFontCollection::FindFontFamily( FontSelectPattern& rFSD ) const
 {
     // give up if no fonts are available
     if( !Count() )
@@ -970,7 +970,7 @@ PhysicalFontFamily* PhysicalFontCollection::FindFontFamily( FontSelectPatternAtt
 
         // Until features are properly supported, they are appended to the
         // font name, so we need to strip them off so the font is found.
-        sal_Int32 nFeat = aSearchName.indexOf(FontSelectPatternAttributes::FEAT_PREFIX);
+        sal_Int32 nFeat = aSearchName.indexOf(FontSelectPattern::FEAT_PREFIX);
         OUString aOrigName = rFSD.maTargetName;
         OUString aBaseFontName = aSearchName.copy( 0, (nFeat != -1) ? nFeat : aSearchName.getLength() );
 
diff --git a/vcl/source/font/PhysicalFontFace.cxx b/vcl/source/font/PhysicalFontFace.cxx
index 5aa39e677dcb..1b0940c8fb76 100644
--- a/vcl/source/font/PhysicalFontFace.cxx
+++ b/vcl/source/font/PhysicalFontFace.cxx
@@ -37,7 +37,7 @@ PhysicalFontFace::PhysicalFontFace( const FontAttributes& rDFA )
             SetSymbolFlag( true );
 }
 
-rtl::Reference<LogicalFontInstance> PhysicalFontFace::CreateFontInstance(const FontSelectPatternAttributes& rFSD) const
+rtl::Reference<LogicalFontInstance> PhysicalFontFace::CreateFontInstance(const FontSelectPattern& rFSD) const
 {
     return new LogicalFontInstance(*this, rFSD);
 }
@@ -89,7 +89,7 @@ sal_Int32 PhysicalFontFace::CompareWithSize( const PhysicalFontFace& rOther ) co
     return 0;
 }
 
-bool PhysicalFontFace::IsBetterMatch( const FontSelectPatternAttributes& rFSD, FontMatchStatus& rStatus ) const
+bool PhysicalFontFace::IsBetterMatch( const FontSelectPattern& rFSD, FontMatchStatus& rStatus ) const
 {
     int nMatch = 0;
 
diff --git a/vcl/source/font/PhysicalFontFamily.cxx b/vcl/source/font/PhysicalFontFamily.cxx
index 9d3107fa461c..6953d259798f 100644
--- a/vcl/source/font/PhysicalFontFamily.cxx
+++ b/vcl/source/font/PhysicalFontFamily.cxx
@@ -195,7 +195,7 @@ void PhysicalFontFamily::InitMatchData( const utl::FontSubstConfiguration& rFont
     mnMatchType |= lcl_IsCJKFont( maFamilyName );
 }
 
-PhysicalFontFace* PhysicalFontFamily::FindBestFontFace( const FontSelectPatternAttributes& rFSD ) const
+PhysicalFontFace* PhysicalFontFamily::FindBestFontFace( const FontSelectPattern& rFSD ) const
 {
     if( maFontFaces.empty() )
         return nullptr;
diff --git a/vcl/source/font/fontcache.cxx b/vcl/source/font/fontcache.cxx
index 4272fd1ef113..82a6261c274c 100644
--- a/vcl/source/font/fontcache.cxx
+++ b/vcl/source/font/fontcache.cxx
@@ -26,12 +26,12 @@
 #include <PhysicalFontFamily.hxx>
 #include <sal/log.hxx>
 
-size_t ImplFontCache::IFSD_Hash::operator()( const FontSelectPatternAttributes& rFSD ) const
+size_t ImplFontCache::IFSD_Hash::operator()( const FontSelectPattern& rFSD ) const
 {
     return rFSD.hashCode();
 }
 
-bool ImplFontCache::IFSD_Equal::operator()(const FontSelectPatternAttributes& rA, const FontSelectPatternAttributes& rB) const
+bool ImplFontCache::IFSD_Equal::operator()(const FontSelectPattern& rA, const FontSelectPattern& rB) const
 {
     // check normalized font family name
     if( rA.maSearchName != rB.maSearchName )
@@ -68,9 +68,9 @@ bool ImplFontCache::IFSD_Equal::operator()(const FontSelectPatternAttributes& rA
     }
 
     // check for features
-    if ((rA.maTargetName.indexOf(FontSelectPatternAttributes::FEAT_PREFIX)
+    if ((rA.maTargetName.indexOf(FontSelectPattern::FEAT_PREFIX)
          != -1 ||
-         rB.maTargetName.indexOf(FontSelectPatternAttributes::FEAT_PREFIX)
+         rB.maTargetName.indexOf(FontSelectPattern::FEAT_PREFIX)
          != -1) && rA.maTargetName != rB.maTargetName)
         return false;
 
@@ -95,12 +95,12 @@ rtl::Reference<LogicalFontInstance> ImplFontCache::GetFontInstance( PhysicalFont
     const vcl::Font& rFont, const Size& rSize, float fExactHeight )
 {
     // initialize internal font request object
-    FontSelectPatternAttributes aFontSelData(rFont, rFont.GetFamilyName(), rSize, fExactHeight);
+    FontSelectPattern aFontSelData(rFont, rFont.GetFamilyName(), rSize, fExactHeight);
     return GetFontInstance( pFontList, aFontSelData );
 }
 
 rtl::Reference<LogicalFontInstance> ImplFontCache::GetFontInstance( PhysicalFontCollection const * pFontList,
-    FontSelectPatternAttributes& aFontSelData )
+    FontSelectPattern& aFontSelData )
 {
     rtl::Reference<LogicalFontInstance> pFontInstance;
     PhysicalFontFamily* pFontFamily = nullptr;
@@ -192,7 +192,7 @@ rtl::Reference<LogicalFontInstance> ImplFontCache::GetFontInstance( PhysicalFont
 }
 
 rtl::Reference<LogicalFontInstance> ImplFontCache::GetGlyphFallbackFont( PhysicalFontCollection const * pFontCollection,
-    FontSelectPatternAttributes& rFontSelData, LogicalFontInstance* pFontInstance, int nFallbackLevel, OUString& rMissingCodes )
+    FontSelectPattern& rFontSelData, LogicalFontInstance* pFontInstance, int nFallbackLevel, OUString& rMissingCodes )
 {
     // get a candidate font for glyph fallback
     // unless the previously selected font got a device specific substitution
diff --git a/vcl/source/font/fontinstance.cxx b/vcl/source/font/fontinstance.cxx
index 218787280228..cf80428f61e2 100644
--- a/vcl/source/font/fontinstance.cxx
+++ b/vcl/source/font/fontinstance.cxx
@@ -40,7 +40,7 @@ namespace std
 }
 
 
-LogicalFontInstance::LogicalFontInstance(const PhysicalFontFace& rFontFace, const FontSelectPatternAttributes& rFontSelData )
+LogicalFontInstance::LogicalFontInstance(const PhysicalFontFace& rFontFace, const FontSelectPattern& rFontSelData )
     : mxFontMetric( new ImplFontMetricData( rFontSelData ))
     , mpConversion( nullptr )
     , mnLineHeight( 0 )
@@ -57,7 +57,7 @@ LogicalFontInstance::LogicalFontInstance(const PhysicalFontFace& rFontFace, cons
 
 void LogicalFontInstance::SetNonAntialiased(bool bNonAntialiased)
 {
-    const_cast<FontSelectPatternAttributes*>(&m_aFontSelData)->mbNonAntialiased = bNonAntialiased;
+    const_cast<FontSelectPattern*>(&m_aFontSelData)->mbNonAntialiased = bNonAntialiased;
 }
 
 LogicalFontInstance::~LogicalFontInstance()
diff --git a/vcl/source/font/fontmetric.cxx b/vcl/source/font/fontmetric.cxx
index d2d6e3a5d210..6ed8fdb97496 100644
--- a/vcl/source/font/fontmetric.cxx
+++ b/vcl/source/font/fontmetric.cxx
@@ -191,7 +191,7 @@ bool ImplFontMetric::operator==( const ImplFontMetric& r ) const
     return true;
 }
 
-ImplFontMetricData::ImplFontMetricData( const FontSelectPatternAttributes& rFontSelData )
+ImplFontMetricData::ImplFontMetricData( const FontSelectPattern& rFontSelData )
     : FontAttributes( rFontSelData )
     , mnHeight ( rFontSelData.mnHeight )
     , mnWidth ( rFontSelData.mnWidth )
diff --git a/vcl/source/font/fontselect.cxx b/vcl/source/font/fontselect.cxx
index ebad5b035944..f879f9c5a7ac 100644
--- a/vcl/source/font/fontselect.cxx
+++ b/vcl/source/font/fontselect.cxx
@@ -27,10 +27,10 @@
 #include <svdata.hxx>
 
 // These mustn't conflict with font name lists which use ; and ,
-const char FontSelectPatternAttributes::FEAT_PREFIX = ':';
-const char FontSelectPatternAttributes::FEAT_SEPARATOR = '&';
+const char FontSelectPattern::FEAT_PREFIX = ':';
+const char FontSelectPattern::FEAT_SEPARATOR = '&';
 
-FontSelectPatternAttributes::FontSelectPatternAttributes( const vcl::Font& rFont,
+FontSelectPattern::FontSelectPattern( const vcl::Font& rFont,
     const OUString& rSearchName, const Size& rSize, float fExactHeight )
     : maSearchName( rSearchName )
     , mnWidth( rSize.Width() )
@@ -65,7 +65,7 @@ FontSelectPatternAttributes::FontSelectPatternAttributes( const vcl::Font& rFont
 
 // NOTE: this ctor is still used on Windows. Do not remove.
 #ifdef _WIN32
-FontSelectPatternAttributes::FontSelectPatternAttributes( const PhysicalFontFace& rFontData,
+FontSelectPattern::FontSelectPattern( const PhysicalFontFace& rFontData,
     const Size& rSize, float fExactHeight, int nOrientation, bool bVertical )
     : FontAttributes( rFontData )
     , mnWidth( rSize.Width() )
@@ -83,12 +83,12 @@ FontSelectPatternAttributes::FontSelectPatternAttributes( const PhysicalFontFace
 
 #endif
 
-size_t FontSelectPatternAttributes::hashCode() const
+size_t FontSelectPattern::hashCode() const
 {
     // TODO: does it pay off to improve this hash function?
     size_t nHash;
     // check for features and generate a unique hash if necessary
-    if (maTargetName.indexOf(FontSelectPatternAttributes::FEAT_PREFIX)
+    if (maTargetName.indexOf(FontSelectPattern::FEAT_PREFIX)
         != -1)
     {
         nHash = maTargetName.hashCode();
@@ -107,7 +107,7 @@ size_t FontSelectPatternAttributes::hashCode() const
     return nHash;
 }
 
-bool FontSelectPatternAttributes::operator==(const FontSelectPatternAttributes& rOther) const
+bool FontSelectPattern::operator==(const FontSelectPattern& rOther) const
 {
     if (!CompareDeviceIndependentFontAttributes(rOther))
         return false;
diff --git a/vcl/source/gdi/CommonSalLayout.cxx b/vcl/source/gdi/CommonSalLayout.cxx
index 9a3d14d69bfc..e4312847d72b 100644
--- a/vcl/source/gdi/CommonSalLayout.cxx
+++ b/vcl/source/gdi/CommonSalLayout.cxx
@@ -304,7 +304,7 @@ bool GenericSalLayout::LayoutText(ImplLayoutArgs& rArgs, const SalLayoutGlyphs*
     hb_buffer_set_unicode_funcs(pHbBuffer, pHbUnicodeFuncs);
 #endif
 
-    const FontSelectPatternAttributes& rFontSelData = mpFont->GetFontSelectPattern();
+    const FontSelectPattern& rFontSelData = mpFont->GetFontSelectPattern();
     if (rArgs.mnFlags & SalLayoutFlags::DisableKerning)
     {
         SAL_INFO("vcl.harfbuzz", "Disabling kerning for font: " << rFontSelData.maTargetName);
diff --git a/vcl/source/gdi/pdfwriter_impl.hxx b/vcl/source/gdi/pdfwriter_impl.hxx
index 941078a0589e..acafb54f587e 100644
--- a/vcl/source/gdi/pdfwriter_impl.hxx
+++ b/vcl/source/gdi/pdfwriter_impl.hxx
@@ -48,7 +48,7 @@
 #include <PhysicalFontFace.hxx>
 
 class StyleSettings;
-class FontSelectPatternAttributes;
+class FontSelectPattern;
 class FontSubsetInfo;
 class ZCodec;
 class EncHashTransporter;
diff --git a/vcl/source/outdev/font.cxx b/vcl/source/outdev/font.cxx
index 32e76283678b..9904ecf304d4 100644
--- a/vcl/source/outdev/font.cxx
+++ b/vcl/source/outdev/font.cxx
@@ -1366,7 +1366,7 @@ std::unique_ptr<SalLayout> OutputDevice::ImplGlyphFallbackLayout( std::unique_pt
     rLayoutArgs.ResetPos();
     OUString aMissingCodes = aMissingCodeBuf.makeStringAndClear();
 
-    FontSelectPatternAttributes aFontSelData(mpFontInstance->GetFontSelectPattern());
+    FontSelectPattern aFontSelData(mpFontInstance->GetFontSelectPattern());
 
     // try if fallback fonts support the missing code units
     for( int nFallbackLevel = 1; nFallbackLevel < MAX_FALLBACK; ++nFallbackLevel )
diff --git a/vcl/source/outdev/text.cxx b/vcl/source/outdev/text.cxx
index a331a204e449..9568b3b50eb2 100644
--- a/vcl/source/outdev/text.cxx
+++ b/vcl/source/outdev/text.cxx
@@ -218,7 +218,7 @@ bool OutputDevice::ImplDrawRotateText( SalLayout& rSalLayout )
     if( !pVDev->SetOutputSizePixel( aBoundRect.GetSize() ) )
         return false;
 
-    const FontSelectPatternAttributes& rPattern = mpFontInstance->GetFontSelectPattern();
+    const FontSelectPattern& rPattern = mpFontInstance->GetFontSelectPattern();
     vcl::Font aFont( GetFont() );
     aFont.SetOrientation( 0 );
     aFont.SetFontSize( Size( rPattern.mnWidth, rPattern.mnHeight ) );
diff --git a/vcl/unx/generic/fontmanager/fontconfig.cxx b/vcl/unx/generic/fontmanager/fontconfig.cxx
index 633f3ab4f914..3c49bb9d00b5 100644
--- a/vcl/unx/generic/fontmanager/fontconfig.cxx
+++ b/vcl/unx/generic/fontmanager/fontconfig.cxx
@@ -862,7 +862,7 @@ IMPL_LINK_NOARG(PrintFontManager, autoInstallFontLangSupport, Timer *, void)
     m_aCurrentRequests.clear();
 }
 
-void PrintFontManager::Substitute(FontSelectPatternAttributes &rPattern, OUString& rMissingCodes)
+void PrintFontManager::Substitute(FontSelectPattern &rPattern, OUString& rMissingCodes)
 {
     FontCfgWrapper& rWrapper = FontCfgWrapper::get();
 
diff --git a/vcl/unx/generic/fontmanager/fontsubst.cxx b/vcl/unx/generic/fontmanager/fontsubst.cxx
index f43ed146e060..034f77bc7be5 100644
--- a/vcl/unx/generic/fontmanager/fontsubst.cxx
+++ b/vcl/unx/generic/fontmanager/fontsubst.cxx
@@ -28,8 +28,8 @@ class FcPreMatchSubstitution
 :   public ImplPreMatchFontSubstitution
 {
 public:
-    bool FindFontSubstitute( FontSelectPatternAttributes& ) const override;
-    typedef ::std::pair<FontSelectPatternAttributes, FontSelectPatternAttributes> value_type;
+    bool FindFontSubstitute( FontSelectPattern& ) const override;
+    typedef ::std::pair<FontSelectPattern, FontSelectPattern> value_type;
 private:
     typedef ::std::list<value_type> CachedFontMapType;
     mutable CachedFontMapType maCachedFontMap;
@@ -40,7 +40,7 @@ class FcGlyphFallbackSubstitution
 {
     // TODO: add a cache
 public:
-    bool FindFontSubstitute(FontSelectPatternAttributes&, LogicalFontInstance* pLogicalFont, OUString& rMissingCodes) const override;
+    bool FindFontSubstitute(FontSelectPattern&, LogicalFontInstance* pLogicalFont, OUString& rMissingCodes) const override;
 };
 
 void SalGenericInstance::RegisterFontSubstitutors( PhysicalFontCollection* pFontCollection )
@@ -54,9 +54,9 @@ void SalGenericInstance::RegisterFontSubstitutors( PhysicalFontCollection* pFont
     pFontCollection->SetFallbackHook( &aSubstFallback );
 }
 
-static FontSelectPatternAttributes GetFcSubstitute(const FontSelectPatternAttributes &rFontSelData, OUString& rMissingCodes)
+static FontSelectPattern GetFcSubstitute(const FontSelectPattern &rFontSelData, OUString& rMissingCodes)
 {
-    FontSelectPatternAttributes aSubstituted(rFontSelData);
+    FontSelectPattern aSubstituted(rFontSelData);
     psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
     rMgr.Substitute(aSubstituted, rMissingCodes);
     return aSubstituted;
@@ -64,7 +64,7 @@ static FontSelectPatternAttributes GetFcSubstitute(const FontSelectPatternAttrib
 
 namespace
 {
-    bool uselessmatch(const FontSelectPatternAttributes &rOrig, const FontSelectPatternAttributes &rNew)
+    bool uselessmatch(const FontSelectPattern &rOrig, const FontSelectPattern &rNew)
     {
         return
           (
@@ -79,9 +79,9 @@ namespace
     class equal
     {
     private:
-        const FontSelectPatternAttributes& mrAttributes;
+        const FontSelectPattern& mrAttributes;
     public:
-        explicit equal(const FontSelectPatternAttributes& rAttributes)
+        explicit equal(const FontSelectPattern& rAttributes)
             : mrAttributes(rAttributes)
         {
         }
@@ -90,7 +90,7 @@ namespace
     };
 }
 
-bool FcPreMatchSubstitution::FindFontSubstitute(FontSelectPatternAttributes &rFontSelData) const
+bool FcPreMatchSubstitution::FindFontSubstitute(FontSelectPattern &rFontSelData) const
 {
     // We don't actually want to talk to Fontconfig at all for symbol fonts
     if( rFontSelData.IsSymbolFont() )
@@ -104,7 +104,7 @@ bool FcPreMatchSubstitution::FindFontSubstitute(FontSelectPatternAttributes &rFo
     //different fonts depending on fontsize, bold, etc settings so don't cache
     //just on the name, cache map all the input and all the output not just map
     //from original selection to output fontname
-    FontSelectPatternAttributes& rPatternAttributes = rFontSelData;
+    FontSelectPattern& rPatternAttributes = rFontSelData;
     CachedFontMapType &rCachedFontMap = maCachedFontMap;
     CachedFontMapType::iterator itr = std::find_if(rCachedFontMap.begin(), rCachedFontMap.end(), equal(rPatternAttributes));
     if (itr != rCachedFontMap.end())
@@ -120,7 +120,7 @@ bool FcPreMatchSubstitution::FindFontSubstitute(FontSelectPatternAttributes &rFo
     }
 
     OUString aDummy;
-    const FontSelectPatternAttributes aOut = GetFcSubstitute( rFontSelData, aDummy );
+    const FontSelectPattern aOut = GetFcSubstitute( rFontSelData, aDummy );
 
     if( aOut.maSearchName.isEmpty() )
         return false;
@@ -155,7 +155,7 @@ bool FcPreMatchSubstitution::FindFontSubstitute(FontSelectPatternAttributes &rFo
     return bHaveSubstitute;
 }
 
-bool FcGlyphFallbackSubstitution::FindFontSubstitute(FontSelectPatternAttributes& rFontSelData,
+bool FcGlyphFallbackSubstitution::FindFontSubstitute(FontSelectPattern& rFontSelData,
     LogicalFontInstance* /*pLogicalFont*/,
     OUString& rMissingCodes ) const
 {
@@ -166,7 +166,7 @@ bool FcGlyphFallbackSubstitution::FindFontSubstitute(FontSelectPatternAttributes
     if ( IsStarSymbol(rFontSelData.maSearchName) )
         return false;
 
-    const FontSelectPatternAttributes aOut = GetFcSubstitute( rFontSelData, rMissingCodes );
+    const FontSelectPattern aOut = GetFcSubstitute( rFontSelData, rMissingCodes );
     // TODO: cache the unicode + srcfont specific result
     // FC doing it would be preferable because it knows the invariables
     // e.g. FC knows the FC rule that all Arial gets replaced by LiberationSans
diff --git a/vcl/unx/generic/gdi/cairotextrender.cxx b/vcl/unx/generic/gdi/cairotextrender.cxx
index 3b250838e785..11d4e94592c4 100644
--- a/vcl/unx/generic/gdi/cairotextrender.cxx
+++ b/vcl/unx/generic/gdi/cairotextrender.cxx
@@ -198,7 +198,7 @@ void CairoTextRender::DrawTextLayout(const GenericSalLayout& rLayout, const SalG
     if (cairo_glyphs.empty())
         return;
 
-    const FontSelectPatternAttributes& rFSD = rInstance.GetFontSelectPattern();
+    const FontSelectPattern& rFSD = rInstance.GetFontSelectPattern();
     int nHeight = rFSD.mnHeight;
     int nWidth = rFSD.mnWidth ? rFSD.mnWidth : nHeight;
     if (nWidth == 0 || nHeight == 0)
diff --git a/vcl/unx/generic/glyphs/freetype_glyphcache.cxx b/vcl/unx/generic/glyphs/freetype_glyphcache.cxx
index 0dd01d679ad0..69da74515515 100644
--- a/vcl/unx/generic/glyphs/freetype_glyphcache.cxx
+++ b/vcl/unx/generic/glyphs/freetype_glyphcache.cxx
@@ -353,7 +353,7 @@ FreetypeFontFace::FreetypeFontFace( FreetypeFontInfo* pFI, const FontAttributes&
 {
 }
 
-rtl::Reference<LogicalFontInstance> FreetypeFontFace::CreateFontInstance(const FontSelectPatternAttributes& rFSD) const
+rtl::Reference<LogicalFontInstance> FreetypeFontFace::CreateFontInstance(const FontSelectPattern& rFSD) const
 {
     return new FreetypeFontInstance(*this, rFSD);
 }
@@ -385,7 +385,7 @@ FreetypeFont::FreetypeFont(LogicalFontInstance* pFontInstance, FreetypeFontInfo*
 
     maFaceFT = pFI->GetFaceFT();
 
-    const FontSelectPatternAttributes& rFSD = pFontInstance->GetFontSelectPattern();
+    const FontSelectPattern& rFSD = pFontInstance->GetFontSelectPattern();
 
     if( rFSD.mnOrientation != 0 )
     {
diff --git a/vcl/unx/generic/glyphs/glyphcache.cxx b/vcl/unx/generic/glyphs/glyphcache.cxx
index b48e3178c35b..cbdfbb1bb87d 100644
--- a/vcl/unx/generic/glyphs/glyphcache.cxx
+++ b/vcl/unx/generic/glyphs/glyphcache.cxx
@@ -85,9 +85,9 @@ size_t GlyphCache::IFSD_Hash::operator()(const rtl::Reference<LogicalFontInstanc
     // TODO: is it worth to improve this hash function?
     sal_uIntPtr nFontId = GetFontId(*rFontInstance);
 
-    const FontSelectPatternAttributes& rFontSelData = rFontInstance->GetFontSelectPattern();
+    const FontSelectPattern& rFontSelData = rFontInstance->GetFontSelectPattern();
 
-    if (rFontSelData.maTargetName.indexOf(FontSelectPatternAttributes::FEAT_PREFIX)
+    if (rFontSelData.maTargetName.indexOf(FontSelectPattern::FEAT_PREFIX)
         != -1)
     {
         OString aFeatName = OUStringToOString( rFontSelData.maTargetName, RTL_TEXTENCODING_UTF8 );
@@ -115,8 +115,8 @@ bool GlyphCache::IFSD_Equal::operator()(const rtl::Reference<LogicalFontInstance
     if (GetFontId(*rAFontInstance) != GetFontId(*rBFontInstance))
         return false;
 
-    const FontSelectPatternAttributes& rA = rAFontInstance->GetFontSelectPattern();
-    const FontSelectPatternAttributes& rB = rBFontInstance->GetFontSelectPattern();
+    const FontSelectPattern& rA = rAFontInstance->GetFontSelectPattern();
+    const FontSelectPattern& rB = rBFontInstance->GetFontSelectPattern();
 
     // compare with the requested metrics
     if( (rA.mnHeight         != rB.mnHeight)
@@ -140,9 +140,9 @@ bool GlyphCache::IFSD_Equal::operator()(const rtl::Reference<LogicalFontInstance
    if (rA.meLanguage != rB.meLanguage)
         return false;
    // check for features
-   if ((rA.maTargetName.indexOf(FontSelectPatternAttributes::FEAT_PREFIX)
+   if ((rA.maTargetName.indexOf(FontSelectPattern::FEAT_PREFIX)
         != -1 ||
-        rB.maTargetName.indexOf(FontSelectPatternAttributes::FEAT_PREFIX)
+        rB.maTargetName.indexOf(FontSelectPattern::FEAT_PREFIX)
         != -1) && rA.maTargetName != rB.maTargetName)
         return false;
 
@@ -354,7 +354,7 @@ void FreetypeFont::GarbageCollect( long nMinLruIndex )
     }
 }
 
-FreetypeFontInstance::FreetypeFontInstance(const PhysicalFontFace& rPFF, const FontSelectPatternAttributes& rFSP)
+FreetypeFontInstance::FreetypeFontInstance(const PhysicalFontFace& rPFF, const FontSelectPattern& rFSP)
     : LogicalFontInstance(rPFF, rFSP)
     , mpFreetypeFont(nullptr)
 {}
diff --git a/vcl/unx/generic/print/genpspgraphics.cxx b/vcl/unx/generic/print/genpspgraphics.cxx
index aa376c7629fe..0fcaad04dc78 100644
--- a/vcl/unx/generic/print/genpspgraphics.cxx
+++ b/vcl/unx/generic/print/genpspgraphics.cxx
@@ -611,7 +611,7 @@ void GenPspGraphics::SetFont(LogicalFontInstance *pFontInstance, int nFallbackLe
 
     sal_IntPtr nID = pFontInstance->GetFontFace()->GetFontId();
 
-    const FontSelectPatternAttributes& rEntry = pFontInstance->GetFontSelectPattern();
+    const FontSelectPattern& rEntry = pFontInstance->GetFontSelectPattern();
 
     // determine which font attributes need to be emulated
     bool bArtItalic = false;
diff --git a/vcl/win/gdi/winlayout.cxx b/vcl/win/gdi/winlayout.cxx
index 2fe463fbc1ef..3800fcd9adc3 100644
--- a/vcl/win/gdi/winlayout.cxx
+++ b/vcl/win/gdi/winlayout.cxx
@@ -311,7 +311,7 @@ std::unique_ptr<SalLayout> WinSalGraphics::GetTextLayout(ImplLayoutArgs& /*rArgs
     return std::unique_ptr<SalLayout>(aLayout);
 }
 
-WinFontInstance::WinFontInstance(const PhysicalFontFace& rPFF, const FontSelectPatternAttributes& rFSP)
+WinFontInstance::WinFontInstance(const PhysicalFontFace& rPFF, const FontSelectPattern& rFSP)
     : LogicalFontInstance(rPFF, rFSP)
     , m_hFont(nullptr)
 {
@@ -325,7 +325,7 @@ WinFontInstance::~WinFontInstance()
 
 bool WinFontInstance::hasHScale() const
 {
-    const FontSelectPatternAttributes &rPattern = GetFontSelectPattern();
+    const FontSelectPattern &rPattern = GetFontSelectPattern();
     int nHeight(rPattern.mnHeight);
     int nWidth(rPattern.mnWidth ? rPattern.mnWidth * GetAverageWidthFactor() : nHeight);
     return nWidth != nHeight;


More information about the Libreoffice-commits mailing list
diff --git a/vcl/win/gdi/salfont.cxx b/vcl/win/gdi/salfont.cxx
index b7069da8e28c..526f924b18d7 100644
--- a/vcl/win/gdi/salfont.cxx
+++ b/vcl/win/gdi/salfont.cxx
@@ -149,7 +149,7 @@ class WinPreMatchFontSubstititution
 :    public ImplPreMatchFontSubstitution
 {
 public:
-    bool FindFontSubstitute(FontSelectPatternAttributes&) const override;
+    bool FindFontSubstitute(FontSelectPattern&) const override;
 };
 
 class WinGlyphFallbackSubstititution
@@ -166,7 +166,7 @@ public:
         ReleaseDC(nullptr, mhDC);
     };
 
-    bool FindFontSubstitute(FontSelectPatternAttributes&, LogicalFontInstance* pLogicalFont, OUString& rMissingChars) const override;
+    bool FindFontSubstitute(FontSelectPattern&, LogicalFontInstance* pLogicalFont, OUString& rMissingChars) const override;
 private:
     HDC mhDC;
     bool HasMissingChars(PhysicalFontFace*, OUString& rMissingChars) const;
@@ -179,10 +179,10 @@ bool WinGlyphFallbackSubstititution::HasMissingChars(PhysicalFontFace* pFace, OU
     FontCharMapRef xFontCharMap = pWinFont->GetFontCharMap();
     if( !xFontCharMap.is() )
     {
         // construct a Size structure as the parameter of constructor of class FontSelectPatternAttributes
         const Size aSize( pFace->GetWidth(), pFace->GetHeight() );
-        // create a FontSelectPatternAttributes object for getting s LOGFONT
-        const FontSelectPatternAttributes aFSD( *pFace, aSize, static_cast<float>(aSize.Height()), 0, false );
+        // create a FontSelectPattern object for getting s LOGFONT
+        const FontSelectPattern aFSD( *pFace, aSize, static_cast<float>(aSize.Height()), 0, false );
         // construct log font
         LOGFONTW aLogFont;
         ImplGetLogFontFromFontSelect( mhDC, &aFSD, pFace, aLogFont );
@@ -257,7 +257,7 @@ static const std::map<OUString, OUString> aBitmapFontSubs =
 };
 
 // TODO: See if Windows have API that we can use here to improve font fallback.
-bool WinPreMatchFontSubstititution::FindFontSubstitute(FontSelectPatternAttributes& rFontSelData) const
+bool WinPreMatchFontSubstititution::FindFontSubstitute(FontSelectPattern& rFontSelData) const
 {
     if (rFontSelData.IsSymbolFont() || IsStarSymbol(rFontSelData.maSearchName))
         return false;
@@ -276,7 +276,7 @@ bool WinPreMatchFontSubstititution::FindFontSubstitute(FontSelectPatternAttribut
 
 // find a fallback font for missing characters
 // TODO: should stylistic matches be searched and preferred?
-bool WinGlyphFallbackSubstititution::FindFontSubstitute(FontSelectPatternAttributes& rFontSelData, LogicalFontInstance* /*pLogicalFont*/, OUString& rMissingChars) const
+bool WinGlyphFallbackSubstititution::FindFontSubstitute(FontSelectPattern& rFontSelData, LogicalFontInstance* /*pLogicalFont*/, OUString& rMissingChars) const
 {
     // guess a locale matching to the missing chars
     LanguageType eLang = rFontSelData.meLanguage;
@@ -660,7 +660,7 @@ sal_IntPtr WinFontFace::GetFontId() const
     return mnId;
 }
 
-rtl::Reference<LogicalFontInstance> WinFontFace::CreateFontInstance(const FontSelectPatternAttributes& rFSD) const
+rtl::Reference<LogicalFontInstance> WinFontFace::CreateFontInstance(const FontSelectPattern& rFSD) const
 {
     return new WinFontInstance(*this, rFSD);
 }
@@ -760,7 +760,7 @@ int CALLBACK SalEnumQueryFontProcExW( const LOGFONTW*,
 }
 
 void ImplGetLogFontFromFontSelect( HDC hDC,
-                                   const FontSelectPatternAttributes* pFont,
+                                   const FontSelectPattern* pFont,
                                    const PhysicalFontFace* pFontFace,
                                    LOGFONTW& rLogFont )
 {
@@ -842,7 +842,7 @@ void ImplGetLogFontFromFontSelect( HDC hDC,
     }
 }
 
-HFONT WinSalGraphics::ImplDoSetFont(FontSelectPatternAttributes const & i_rFont,
+HFONT WinSalGraphics::ImplDoSetFont(FontSelectPattern const & i_rFont,
                                     const PhysicalFontFace * i_pFontFace,
                                     float& o_rFontScale,
                                     HFONT& o_rOldFont)
@@ -1647,10 +1647,10 @@ bool WinSalGraphics::CreateFontSubset( const OUString& rToFile,
 {
     // TODO: use more of the central font-subsetting code, move stuff there if needed
 
     // create matching FontSelectPatternAttributes
     // we need just enough to get to the font file data
     // use height=1000 for easier debugging (to match psprint's font units)
-    FontSelectPatternAttributes aIFSD( *pFont, Size(0,1000), 1000.0, 0, false );
+    FontSelectPattern aIFSD( *pFont, Size(0,1000), 1000.0, 0, false );
 
     // TODO: much better solution: move SetFont and restoration of old font to caller
     ScopedFont aOldFont(*this);
@@ -1769,9 +1769,9 @@ bool WinSalGraphics::CreateFontSubset( const OUString& rToFile,
 
 const void* WinSalGraphics::GetEmbedFontData(const PhysicalFontFace* pFont, long* pDataLen)
 {
     // create matching FontSelectPatternAttributes
     // we need just enough to get to the font file data
-    FontSelectPatternAttributes aIFSD( *pFont, Size(0,1000), 1000.0, 0, false );
+    FontSelectPattern aIFSD( *pFont, Size(0,1000), 1000.0, 0, false );
 
     ScopedFont aOldFont(*this);
 
@@ -1799,9 +1799,9 @@ void WinSalGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                      std::vector< sal_Int32 >& rWidths,
                                      Ucs2UIntMap& rUnicodeEnc )
 {
     // create matching FontSelectPatternAttributes
     // we need just enough to get to the font file data
-    FontSelectPatternAttributes aIFSD( *pFont, Size(0,1000), 1000.0, 0, false );
+    FontSelectPattern aIFSD( *pFont, Size(0,1000), 1000.0, 0, false );
 
     // TODO: much better solution: move SetFont and restoration of old font to caller
     ScopedFont aOldFont(*this);
@@ -179,10 +179,10 @@ bool WinGlyphFallbackSubstititution::HasMissingChars(PhysicalFontFace* pFace, OU
     if( !xFontCharMap.is() )
     {
-        // construct a Size structure as the parameter of constructor of class FontSelectPatternAttributes
+        // construct a Size structure as the parameter of constructor of class FontSelectPattern
         const Size aSize( pFace->GetWidth(), pFace->GetHeight() );
@@ -1647,10 +1647,10 @@ bool WinSalGraphics::CreateFontSubset( const OUString& rToFile,
     // TODO: use more of the central font-subsetting code, move stuff there if needed
 
-    // create matching FontSelectPatternAttributes
+    // create matching FontSelectPattern
     // we need just enough to get to the font file data
     // use height=1000 for easier debugging (to match psprint's font units)
@@ -1769,9 +1769,9 @@ bool WinSalGraphics::CreateFontSubset( const OUString& rToFile,
 const void* WinSalGraphics::GetEmbedFontData(const PhysicalFontFace* pFont, long* pDataLen)
 {
-    // create matching FontSelectPatternAttributes
+    // create matching FontSelectPattern
     // we need just enough to get to the font file data
@@ -1799,9 +1799,9 @@ void WinSalGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                      Ucs2UIntMap& rUnicodeEnc )
 {
-    // create matching FontSelectPatternAttributes
+    // create matching FontSelectPattern
     // we need just enough to get to the font file data